pychemia.crystal package
========================

.. automodule:: pychemia.crystal
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pychemia.crystal.tests

Submodules
----------

pychemia.crystal.kpoints module
-------------------------------

.. automodule:: pychemia.crystal.kpoints
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.crystal.lattice module
-------------------------------

.. automodule:: pychemia.crystal.lattice
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.crystal.symmetry module
--------------------------------

.. automodule:: pychemia.crystal.symmetry
    :members:
    :undoc-members:
    :show-inheritance:


pychemia.crystal.samples module
-------------------------------

.. automodule:: pychemia.crystal.samples
    :members:
    :undoc-members:
    :show-inheritance:
